@@ -19,23 +19,25 @@ from __future__ import annotations
 import json
 import time
 from enum import Enum
-from functools import wraps
+from functools import cached_property, wraps
 from inspect import signature
-from typing import Any, Callable, Sequence, Set, TypeVar, cast
+from typing import TYPE_CHECKING, Any, Callable, Sequence, Set, TypeVar, cast
 
 import aiohttp
 from aiohttp import ClientResponseError
 from asgiref.sync import sync_to_async
-from requests import PreparedRequest, Session
 from requests.auth import AuthBase
-from requests.models import Response
+from requests.sessions import Session
 
-from airflow.compat.functools import cached_property
 from airflow.exceptions import AirflowException
-from airflow.models import Connection
 from airflow.providers.http.hooks.http import HttpHook
 from airflow.typing_compat import TypedDict
 
+if TYPE_CHECKING:
+    from requests.models import PreparedRequest, Response
+
+    from airflow.models import Connection
+
 
 def fallback_to_default_account(func: Callable) -> Callable:
     """
@@ -189,7 +191,7 @@ class DbtCloudHook(HttpHook):
         tenant: str, endpoint: str, include_related: list[str] | None = None
     ) -> tuple[str, dict[str, Any]]:
         """
-        Form URL from base url and endpoint url
+        Form URL from base url and endpoint url.
 
         :param tenant: The tenant domain name which is need to be replaced in base url.
         :param endpoint: Endpoint url to be requested.
@@ -203,7 +205,7 @@ class DbtCloudHook(HttpHook):
         return url, data
 
     async def get_headers_tenants_from_connection(self) -> tuple[dict[str, Any], str]:
-        """Get Headers, tenants from the connection details"""
+        """Get Headers, tenants from the connection details."""
         headers: dict[str, Any] = {}
         connection: Connection = await sync_to_async(self.get_connection)(self.dbt_cloud_conn_id)
         tenant = self._get_tenant_domain(connection)
